# openapi_client.BusinessApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_collection**](BusinessApi.md#create_collection) | **POST** /business/collections | Create collection
[**create_product**](BusinessApi.md#create_product) | **POST** /business/products | Create product
[**delete_collection**](BusinessApi.md#delete_collection) | **DELETE** /business/collections/{CollectionID} | Delete collection
[**delete_product**](BusinessApi.md#delete_product) | **DELETE** /business/products/{ProductID} | Delete product
[**edit_business_profile**](BusinessApi.md#edit_business_profile) | **POST** /business | Edit your Business Profile
[**edit_collection**](BusinessApi.md#edit_collection) | **PATCH** /business/collections/{CollectionID} | Edit collection
[**get_business_profile**](BusinessApi.md#get_business_profile) | **GET** /business | Get business profile
[**get_collection**](BusinessApi.md#get_collection) | **GET** /business/collections/{CollectionID} | Get collection
[**get_collections_list**](BusinessApi.md#get_collections_list) | **GET** /business/collections | Get collections
[**get_contact_products**](BusinessApi.md#get_contact_products) | **GET** /business/{ContactID}/products | Get products by Contact ID
[**get_order_items**](BusinessApi.md#get_order_items) | **GET** /business/orders/{OrderID} | Get order items
[**get_product**](BusinessApi.md#get_product) | **GET** /business/products/{ProductID} | Get product
[**get_products**](BusinessApi.md#get_products) | **GET** /business/products | Get products
[**send_catalog**](BusinessApi.md#send_catalog) | **POST** /business/catalogs/{ContactID} | Send catalog by Contact ID (phone number)
[**send_product**](BusinessApi.md#send_product) | **POST** /business/products/{ProductID} | Send product
[**update_product**](BusinessApi.md#update_product) | **PATCH** /business/products/{ProductID} | Update product


# **create_collection**
> BusinessCollectionEditResult create_collection(business_collection_create)

Create collection

Create business collection

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_collection_create import BusinessCollectionCreate
from openapi_client.models.business_collection_edit_result import BusinessCollectionEditResult
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    business_collection_create = openapi_client.BusinessCollectionCreate() # BusinessCollectionCreate | Business collection parameters

    try:
        # Create collection
        api_response = api_instance.create_collection(business_collection_create)
        print("The response of BusinessApi->create_collection:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->create_collection: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **business_collection_create** | [**BusinessCollectionCreate**](BusinessCollectionCreate.md)| Business collection parameters | 

### Return type

[**BusinessCollectionEditResult**](BusinessCollectionEditResult.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Business Collection Edit Result |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for creating collection |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_product**
> Product create_product(product_create=product_create)

Create product

In this method you will be able to register a product in your catalog

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.product import Product
from openapi_client.models.product_create import ProductCreate
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    product_create = openapi_client.ProductCreate() # ProductCreate | Request body (optional)

    try:
        # Create product
        api_response = api_instance.create_product(product_create=product_create)
        print("The response of BusinessApi->create_product:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->create_product: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_create** | [**ProductCreate**](ProductCreate.md)| Request body | [optional] 

### Return type

[**Product**](Product.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_collection**
> ResponseSuccess delete_collection(collection_id)

Delete collection

Method to delete business collection

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    collection_id = 'collection_id_example' # str | Collection ID

    try:
        # Delete collection
        api_response = api_instance.delete_collection(collection_id)
        print("The response of BusinessApi->delete_collection:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->delete_collection: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **collection_id** | **str**| Collection ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization to delete collection |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_product**
> ResponseSuccess delete_product(product_id)

Delete product

In this method you will be able to delete a product by its ID

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    product_id = 'product_id_example' # str | Product ID

    try:
        # Delete product
        api_response = api_instance.delete_product(product_id)
        print("The response of BusinessApi->delete_product:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->delete_product: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **str**| Product ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for update product |  -  |
**404** | Specified product not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **edit_business_profile**
> ResponseSuccess edit_business_profile(business_profile_custom=business_profile_custom)

Edit your Business Profile

The method allows you to edit information of your WhatsApp Business profile

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_profile_custom import BusinessProfileCustom
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    business_profile_custom = openapi_client.BusinessProfileCustom() # BusinessProfileCustom | Request body (optional)

    try:
        # Edit your Business Profile
        api_response = api_instance.edit_business_profile(business_profile_custom=business_profile_custom)
        print("The response of BusinessApi->edit_business_profile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->edit_business_profile: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **business_profile_custom** | [**BusinessProfileCustom**](BusinessProfileCustom.md)| Request body | [optional] 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **edit_collection**
> BusinessCollectionEditResult edit_collection(collection_id, business_collection_edit)

Edit collection

With this method you will be able to edit business collection

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_collection_edit import BusinessCollectionEdit
from openapi_client.models.business_collection_edit_result import BusinessCollectionEditResult
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    collection_id = 'collection_id_example' # str | Collection ID
    business_collection_edit = openapi_client.BusinessCollectionEdit() # BusinessCollectionEdit | Business collection edit parameters

    try:
        # Edit collection
        api_response = api_instance.edit_collection(collection_id, business_collection_edit)
        print("The response of BusinessApi->edit_collection:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->edit_collection: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **collection_id** | **str**| Collection ID | 
 **business_collection_edit** | [**BusinessCollectionEdit**](BusinessCollectionEdit.md)| Business collection edit parameters | 

### Return type

[**BusinessCollectionEditResult**](BusinessCollectionEditResult.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Business Collection Edit Result |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for editing collection |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_business_profile**
> BusinessProfile get_business_profile()

Get business profile

The method allows you to get information about your WhatsApp Business profile

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_profile import BusinessProfile
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)

    try:
        # Get business profile
        api_response = api_instance.get_business_profile()
        print("The response of BusinessApi->get_business_profile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_business_profile: %s\n" % e)
```



### Parameters

This endpoint does not need any parameter.

### Return type

[**BusinessProfile**](BusinessProfile.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Business Profile |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_collection**
> BusinessCollection get_collection(collection_id)

Get collection

With this method you will be able to get business collection

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_collection import BusinessCollection
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    collection_id = 'collection_id_example' # str | Collection ID

    try:
        # Get collection
        api_response = api_instance.get_collection(collection_id)
        print("The response of BusinessApi->get_collection:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_collection: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **collection_id** | **str**| Collection ID | 

### Return type

[**BusinessCollection**](BusinessCollection.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Business Collection |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting collection |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_collections_list**
> BusinessCollectionList get_collections_list(count=count, offset=offset)

Get collections

With this method you will be able to get the collections list from a Whatsapp Business catalog

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.business_collection_list import BusinessCollectionList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)

    try:
        # Get collections
        api_response = api_instance.get_collections_list(count=count, offset=offset)
        print("The response of BusinessApi->get_collections_list:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_collections_list: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 

### Return type

[**BusinessCollectionList**](BusinessCollectionList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Business Collection List |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting collection |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_contact_products**
> ProductsList get_contact_products(contact_id, count=count, offset=offset)

Get products by Contact ID

This method allows you to get the catalog and products by [Chat ID](https://support.whapi.cloud/help-desk/faq/chat-id.-what-is-it-and-how-to-get-it), even if it is not in your contact list

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.products_list import ProductsList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    contact_id = 'contact_id_example' # str | Contact ID
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)

    try:
        # Get products by Contact ID
        api_response = api_instance.get_contact_products(contact_id, count=count, offset=offset)
        print("The response of BusinessApi->get_contact_products:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_contact_products: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contact_id** | **str**| Contact ID | 
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 

### Return type

[**ProductsList**](ProductsList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**404** | Specified user not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_order_items**
> OrderItems get_order_items(order_id, order_token=order_token)

Get order items

The method allows you to get information about the items in the shopping cart sent to you in messages. Note! Use the token as a Query (as in a get request). [More details in the knowledge base](https://support.whapi.cloud/help-desk/receiving/http-api/get-order-items)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.order_items import OrderItems
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    order_id = 'order_id_example' # str | Order ID
    order_token = 'order_token_example' # str | Base64 token from order for receiving information (optional)

    try:
        # Get order items
        api_response = api_instance.get_order_items(order_id, order_token=order_token)
        print("The response of BusinessApi->get_order_items:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_order_items: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **order_id** | **str**| Order ID | 
 **order_token** | **str**| Base64 token from order for receiving information | [optional] 

### Return type

[**OrderItems**](OrderItems.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**401** | Need channel authorization for getting products |  -  |
**403** | Need order token for getting products |  -  |
**404** | Specified order not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_product**
> Product get_product(product_id)

Get product

In this method you will be able to get your product by its ID

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.product import Product
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    product_id = 'product_id_example' # str | Product ID

    try:
        # Get product
        api_response = api_instance.get_product(product_id)
        print("The response of BusinessApi->get_product:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_product: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **str**| Product ID | 

### Return type

[**Product**](Product.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**404** | Specified product not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_products**
> ProductsList get_products(count=count, offset=offset)

Get products

With this method you will be able to get the products from a Whatsapp Business catalog

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.products_list import ProductsList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)

    try:
        # Get products
        api_response = api_instance.get_products(count=count, offset=offset)
        print("The response of BusinessApi->get_products:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->get_products: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 

### Return type

[**ProductsList**](ProductsList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting products |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_catalog**
> SentMessage send_catalog(contact_id, sender_catalog_by_id)

Send catalog by Contact ID (phone number)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_catalog_by_id import SenderCatalogByID
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    contact_id = 'contact_id_example' # str | Contact ID
    sender_catalog_by_id = openapi_client.SenderCatalogByID() # SenderCatalogByID | Message catalog

    try:
        # Send catalog by Contact ID (phone number)
        api_response = api_instance.send_catalog(contact_id, sender_catalog_by_id)
        print("The response of BusinessApi->send_catalog:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->send_catalog: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contact_id** | **str**| Contact ID | 
 **sender_catalog_by_id** | [**SenderCatalogByID**](SenderCatalogByID.md)| Message catalog | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send catalog |  -  |
**404** | Specified contact not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_product**
> SentMessage send_product(product_id, sender_product_from_catalog)

Send product

The method is for sending an item from your catalog

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_product_from_catalog import SenderProductFromCatalog
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    product_id = 'product_id_example' # str | Product ID
    sender_product_from_catalog = openapi_client.SenderProductFromCatalog() # SenderProductFromCatalog | Message product

    try:
        # Send product
        api_response = api_instance.send_product(product_id, sender_product_from_catalog)
        print("The response of BusinessApi->send_product:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->send_product: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **str**| Product ID | 
 **sender_product_from_catalog** | [**SenderProductFromCatalog**](SenderProductFromCatalog.md)| Message product | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for add contact |  -  |
**404** | Specified product not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_product**
> Product update_product(product_id, product_edit)

Update product

The *images* field is required and must contain all images

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.product import Product
from openapi_client.models.product_edit import ProductEdit
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.BusinessApi(api_client)
    product_id = 'product_id_example' # str | Product ID
    product_edit = openapi_client.ProductEdit() # ProductEdit | Message product

    try:
        # Update product
        api_response = api_instance.update_product(product_id, product_edit)
        print("The response of BusinessApi->update_product:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling BusinessApi->update_product: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **str**| Product ID | 
 **product_edit** | [**ProductEdit**](ProductEdit.md)| Message product | 

### Return type

[**Product**](Product.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for update product |  -  |
**404** | Specified product not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

