# openapi_client.ContactsApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**check_phones**](ContactsApi.md#check_phones) | **POST** /contacts | Check phones
[**get_contact**](ContactsApi.md#get_contact) | **GET** /contacts/{ContactID} | Get contact
[**get_contact_profile**](ContactsApi.md#get_contact_profile) | **GET** /contacts/{ContactID}/profile | Get profile
[**get_contacts**](ContactsApi.md#get_contacts) | **GET** /contacts | Get contacts
[**send_contact**](ContactsApi.md#send_contact) | **POST** /contacts/{ContactID} | Send contact


# **check_phones**
> CheckContactResponse check_phones(check_contact_request)

Check phones

This method returns whether or not the number has Whatsapp. Batch check provisioning is supported, and there is no batch check limit. However, an atypical mass check can draw attention to your number, so we advise [balancing the check between channels](https://support.whapi.cloud/help-desk/faq/checking-if-the-number-has-whatsapp)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.check_contact_request import CheckContactRequest
from openapi_client.models.check_contact_response import CheckContactResponse
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ContactsApi(api_client)
    check_contact_request = {"blocking":"wait","contacts":["{{Recipient-WA-ID}}"]} # CheckContactRequest | Contact data

    try:
        # Check phones
        api_response = api_instance.check_phones(check_contact_request)
        print("The response of ContactsApi->check_phones:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContactsApi->check_phones: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **check_contact_request** | [**CheckContactRequest**](CheckContactRequest.md)| Contact data | 

### Return type

[**CheckContactResponse**](CheckContactResponse.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for check phones |  -  |
**402** | Trial version limit exceeded |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_contact**
> Contact get_contact(contact_id)

Get contact

This method is responsible for returning all of you contact’s metadata

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.contact import Contact
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ContactsApi(api_client)
    contact_id = 'contact_id_example' # str | Contact ID

    try:
        # Get contact
        api_response = api_instance.get_contact(contact_id)
        print("The response of ContactsApi->get_contact:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContactsApi->get_contact: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contact_id** | **str**| Contact ID | 

### Return type

[**Contact**](Contact.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified contact not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_contact_profile**
> UserProfile get_contact_profile(contact_id)

Get profile

This method allows you to get profile information (description, profile image) by phone number, even if it is not in your contact list

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.user_profile import UserProfile
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ContactsApi(api_client)
    contact_id = 'contact_id_example' # str | Contact ID

    try:
        # Get profile
        api_response = api_instance.get_contact_profile(contact_id)
        print("The response of ContactsApi->get_contact_profile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContactsApi->get_contact_profile: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contact_id** | **str**| Contact ID | 

### Return type

[**UserProfile**](UserProfile.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for getting user info |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Specified user not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_contacts**
> ContactsList get_contacts(count=count, offset=offset)

Get contacts

This method is responsible for returning all of your Whatsapp contacts

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.contacts_list import ContactsList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ContactsApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)

    try:
        # Get contacts
        api_response = api_instance.get_contacts(count=count, offset=offset)
        print("The response of ContactsApi->get_contacts:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContactsApi->get_contacts: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 

### Return type

[**ContactsList**](ContactsList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified contact not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_contact**
> SentMessage send_contact(contact_id, sender_contact_from_phonebook)

Send contact

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_contact_from_phonebook import SenderContactFromPhonebook
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ContactsApi(api_client)
    contact_id = 'contact_id_example' # str | Contact ID
    sender_contact_from_phonebook = openapi_client.SenderContactFromPhonebook() # SenderContactFromPhonebook | Message contact

    try:
        # Send contact
        api_response = api_instance.send_contact(contact_id, sender_contact_from_phonebook)
        print("The response of ContactsApi->send_contact:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContactsApi->send_contact: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **contact_id** | **str**| Contact ID | 
 **sender_contact_from_phonebook** | [**SenderContactFromPhonebook**](SenderContactFromPhonebook.md)| Message contact | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for add contact |  -  |
**404** | Specified contact not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

