# openapi_client.MediaApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_media**](MediaApi.md#delete_media) | **DELETE** /media/{MediaID} | Delete media
[**get_media**](MediaApi.md#get_media) | **GET** /media/{MediaID} | Get media
[**get_media_files**](MediaApi.md#get_media_files) | **GET** /media | Get media files
[**upload_media**](MediaApi.md#upload_media) | **POST** /media | Upload media


# **delete_media**
> ResponseSuccess delete_media(media_id)

Delete media

Delete a file from the cloud by ID

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MediaApi(api_client)
    media_id = 'media_id_example' # str | Media ID

    try:
        # Delete media
        api_response = api_instance.delete_media(media_id)
        print("The response of MediaApi->delete_media:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MediaApi->delete_media: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **media_id** | **str**| Media ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified media not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_media**
> bytearray get_media(media_id)

Get media

Receive a file from the cloud by ID. [Read more about file storage period.](https://support.whapi.cloud/help-desk/receiving/file-expiration-period)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MediaApi(api_client)
    media_id = 'media_id_example' # str | Media ID

    try:
        # Get media
        api_response = api_instance.get_media(media_id)
        print("The response of MediaApi->get_media:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MediaApi->get_media: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **media_id** | **str**| Media ID | 

### Return type

**bytearray**

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/pdf, application/msword, application/vnd.ms-powerpoint, application/vnd.ms-excel, text/plain, image/jpeg, image/png, audio/acc, audio/mp4, audio/amr, audio/mpeg, audio/ogg, codecs=opus, video/mp4, application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified media not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_media_files**
> MediaFilesList get_media_files(count=count, offset=offset, time_from=time_from, time_to=time_to, sort=sort)

Get media files

This method is responsible for returning all of your media files

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.media_files_list import MediaFilesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MediaApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)
    time_from = 3.4 # float | Timestamp from which to get objects (optional)
    time_to = 3.4 # float | Timestamp up to which to get objects (optional)
    sort = 'sort_example' # str | Order for items in request (optional)

    try:
        # Get media files
        api_response = api_instance.get_media_files(count=count, offset=offset, time_from=time_from, time_to=time_to, sort=sort)
        print("The response of MediaApi->get_media_files:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MediaApi->get_media_files: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 
 **time_from** | **float**| Timestamp from which to get objects | [optional] 
 **time_to** | **float**| Timestamp up to which to get objects | [optional] 
 **sort** | **str**| Order for items in request | [optional] 

### Return type

[**MediaFilesList**](MediaFilesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **upload_media**
> UploadMediaResponse upload_media(body)

Upload media

This method is used to upload a file to cloud storage. In the response, you will receive the MediaID for the uploaded file, which can be used later, for example, to send media messages. The file type are determined by the file extension. [Read more about file storage period.](https://support.whapi.cloud/help-desk/receiving/file-expiration-period)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.upload_media_response import UploadMediaResponse
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MediaApi(api_client)
    body = None # bytearray | 

    try:
        # Upload media
        api_response = api_instance.upload_media(body)
        print("The response of MediaApi->upload_media:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MediaApi->upload_media: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **bytearray**|  | 

### Return type

[**UploadMediaResponse**](UploadMediaResponse.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/pdf, application/msword, application/vnd.ms-powerpoint, application/vnd.ms-excel, text/plain, image/jpeg, image/png, audio/acc, audio/mp4, audio/amr, audio/mpeg, audio/ogg, codecs=opus, video/mp4, application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** |  |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for upload media |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

