# openapi_client.MessagesApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_message**](MessagesApi.md#delete_message) | **DELETE** /messages/{MessageID} | ❌ Delete message
[**forward_message**](MessagesApi.md#forward_message) | **POST** /messages/{MessageID} | ↪ Forward message
[**get_message**](MessagesApi.md#get_message) | **GET** /messages/{MessageID} | Get message
[**get_messages**](MessagesApi.md#get_messages) | **GET** /messages/list | Get messages
[**get_messages_by_chat_id**](MessagesApi.md#get_messages_by_chat_id) | **GET** /messages/list/{ChatID} | Get messages by chat ID
[**mark_message_as_read**](MessagesApi.md#mark_message_as_read) | **PUT** /messages/{MessageID} | ✔✔ Mark message as read
[**react_to_message**](MessagesApi.md#react_to_message) | **PUT** /messages/{MessageID}/reaction | 😍 React to message
[**send_media_message**](MessagesApi.md#send_media_message) | **POST** /messages/media/{MediaMessageType} | 📎 Send media message
[**send_message_audio**](MessagesApi.md#send_message_audio) | **POST** /messages/audio | 🎵 Send media-audio message
[**send_message_contact**](MessagesApi.md#send_message_contact) | **POST** /messages/contact | 👤 Send contact message
[**send_message_contact_list**](MessagesApi.md#send_message_contact_list) | **POST** /messages/contact_list | 👥 Send contact list message
[**send_message_document**](MessagesApi.md#send_message_document) | **POST** /messages/document | 📑 Send media-document message
[**send_message_gif**](MessagesApi.md#send_message_gif) | **POST** /messages/gif | 🎬 Send media-gif message
[**send_message_image**](MessagesApi.md#send_message_image) | **POST** /messages/image | 🖼 Send media-image message
[**send_message_interactive**](MessagesApi.md#send_message_interactive) | **POST** /messages/interactive | 🎮 Send interactive message
[**send_message_link_preview**](MessagesApi.md#send_message_link_preview) | **POST** /messages/link_preview | 📎 Send link preview message
[**send_message_live_location**](MessagesApi.md#send_message_live_location) | **POST** /messages/live_location | 🧭 Send live location message
[**send_message_location**](MessagesApi.md#send_message_location) | **POST** /messages/location | 📍 Send location message
[**send_message_poll**](MessagesApi.md#send_message_poll) | **POST** /messages/poll | 📊 Send poll message
[**send_message_short**](MessagesApi.md#send_message_short) | **POST** /messages/short | 📹 Send media-short video message (PTV)
[**send_message_sticker**](MessagesApi.md#send_message_sticker) | **POST** /messages/sticker | 🎭 Send media-sticker message
[**send_message_story**](MessagesApi.md#send_message_story) | **POST** /messages/story | 👁️‍🗨️ Send story message
[**send_message_story_audio**](MessagesApi.md#send_message_story_audio) | **POST** /messages/story/audio | 🎵️ Send story audio message
[**send_message_story_media**](MessagesApi.md#send_message_story_media) | **POST** /messages/story/media | 🖼 Send story media message
[**send_message_story_text**](MessagesApi.md#send_message_story_text) | **POST** /messages/story/text | 💬 Send story text message
[**send_message_text**](MessagesApi.md#send_message_text) | **POST** /messages/text | 💬 Send text message
[**send_message_video**](MessagesApi.md#send_message_video) | **POST** /messages/video | 🎥 Send media-video message
[**send_message_voice**](MessagesApi.md#send_message_voice) | **POST** /messages/voice | 🎤 Send media-voice message
[**star_message**](MessagesApi.md#star_message) | **PUT** /messages/{MessageID}/star | ⭐ Star message


# **delete_message**
> ResponseSuccess delete_message(message_id)

❌ Delete message

Method used to delete a text sent in a chat. You will be able to delete a message that you sent as well as a message that was sent by a contact. To use this resource you will only need the messageId of the message that you want to delete.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID

    try:
        # ❌ Delete message
        api_response = api_instance.delete_message(message_id)
        print("The response of MessagesApi->delete_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->delete_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for delete message |  -  |
**404** | Specified message not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **forward_message**
> SentMessage forward_message(message_id, forward_message)

↪ Forward message

Simple and straightforward, in this method, you can forward messages through the API by providing the messageId of the message you want to forward and the phone number of the chat where this messageId is located.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.forward_message import ForwardMessage
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID
    forward_message = openapi_client.ForwardMessage() # ForwardMessage | Forward message

    try:
        # ↪ Forward message
        api_response = api_instance.forward_message(message_id, forward_message)
        print("The response of MessagesApi->forward_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->forward_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 
 **forward_message** | [**ForwardMessage**](ForwardMessage.md)| Forward message | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for forward message |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Specified message not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_message**
> Message get_message(message_id)

Get message

The method returns a message from any chat by message id.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.message import Message
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID

    try:
        # Get message
        api_response = api_instance.get_message(message_id)
        print("The response of MessagesApi->get_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->get_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 

### Return type

[**Message**](Message.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified message not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_messages**
> MessagesList get_messages(count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me, sort=sort)

Get messages

The method contains a list of all received and sent messages in a particular chat. Sorting by descending date of message sending.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.messages_list import MessagesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)
    time_from = 3.4 # float | Timestamp from which to get objects (optional)
    time_to = 3.4 # float | Timestamp up to which to get objects (optional)
    normal_types = True # bool | If false, include system messages (optional)
    author = 'author_example' # str | To filter by author (Contact ID) (optional)
    from_me = True # bool | If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. (optional)
    sort = 'sort_example' # str | Order for items in request (optional)

    try:
        # Get messages
        api_response = api_instance.get_messages(count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me, sort=sort)
        print("The response of MessagesApi->get_messages:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->get_messages: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 
 **time_from** | **float**| Timestamp from which to get objects | [optional] 
 **time_to** | **float**| Timestamp up to which to get objects | [optional] 
 **normal_types** | **bool**| If false, include system messages | [optional] 
 **author** | **str**| To filter by author (Contact ID) | [optional] 
 **from_me** | **bool**| If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. | [optional] 
 **sort** | **str**| Order for items in request | [optional] 

### Return type

[**MessagesList**](MessagesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_messages_by_chat_id**
> MessagesList get_messages_by_chat_id(chat_id, count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me, sort=sort)

Get messages by chat ID

The method contains a list of all received and sent messages in a particular chat. Sorting by descending date of message sending. You will need to specify [Chat ID](https://support.whapi.cloud/help-desk/faq/chat-id.-what-is-it-and-how-to-get-it)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.messages_list import MessagesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    chat_id = 'chat_id_example' # str | Chat ID
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)
    time_from = 3.4 # float | Timestamp from which to get objects (optional)
    time_to = 3.4 # float | Timestamp up to which to get objects (optional)
    normal_types = True # bool | If false, include system messages (optional)
    author = 'author_example' # str | To filter by author (Contact ID) (optional)
    from_me = True # bool | If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. (optional)
    sort = 'sort_example' # str | Order for items in request (optional)

    try:
        # Get messages by chat ID
        api_response = api_instance.get_messages_by_chat_id(chat_id, count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me, sort=sort)
        print("The response of MessagesApi->get_messages_by_chat_id:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->get_messages_by_chat_id: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **chat_id** | **str**| Chat ID | 
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 
 **time_from** | **float**| Timestamp from which to get objects | [optional] 
 **time_to** | **float**| Timestamp up to which to get objects | [optional] 
 **normal_types** | **bool**| If false, include system messages | [optional] 
 **author** | **str**| To filter by author (Contact ID) | [optional] 
 **from_me** | **bool**| If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. | [optional] 
 **sort** | **str**| Order for items in request | [optional] 

### Return type

[**MessagesList**](MessagesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified chat not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **mark_message_as_read**
> ResponseSuccess mark_message_as_read(message_id)

✔✔ Mark message as read

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID

    try:
        # ✔✔ Mark message as read
        api_response = api_instance.mark_message_as_read(message_id)
        print("The response of MessagesApi->mark_message_as_read:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->mark_message_as_read: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for mark as read message |  -  |
**404** | Specified message not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **react_to_message**
> ResponseSuccess react_to_message(message_id, react_to_message)

😍 React to message

In this method you will be able to react to messages that were sent or recieved by you. You will need to specify the ID of the message you will respond to, as well as [the emoji](https://support.whapi.cloud/help-desk/sending/send-emoji)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.react_to_message import ReactToMessage
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID
    react_to_message = openapi_client.ReactToMessage() # ReactToMessage | React to message

    try:
        # 😍 React to message
        api_response = api_instance.react_to_message(message_id, react_to_message)
        print("The response of MessagesApi->react_to_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->react_to_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 
 **react_to_message** | [**ReactToMessage**](ReactToMessage.md)| React to message | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for react to message |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Specified message not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_media_message**
> SentMessage send_media_message(media_message_type, send_params, body)

📎 Send media message

Additional endpoint for easy send media-file as message. Use request body as file and inpath parameters for send parameters. Media message can be one of the following types: - 📷 image - 🎥 video - 🎬 gif - 🎵 audio - 🎤 voice - 📄 document - 🎭 sticker 

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.media_message_type import MediaMessageType
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    media_message_type = openapi_client.MediaMessageType() # MediaMessageType | Media message type
    send_params = {'key': openapi_client.SenderMedia()} # SenderMedia | Send sender parameters via query
    body = None # bytearray | 

    try:
        # 📎 Send media message
        api_response = api_instance.send_media_message(media_message_type, send_params, body)
        print("The response of MessagesApi->send_media_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_media_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **media_message_type** | [**MediaMessageType**](.md)| Media message type | 
 **send_params** | [**SenderMedia**](.md)| Send sender parameters via query | 
 **body** | **bytearray**|  | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/pdf, application/msword, application/vnd.ms-powerpoint, application/vnd.ms-excel, text/plain, image/jpeg, image/png, audio/acc, audio/mp4, audio/amr, audio/mpeg, audio/ogg, codecs=opus, video/mp4, application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_audio**
> SentMessage send_message_audio(sender_audio)

🎵 Send media-audio message

This method is responsible for sending audio messages for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_audio import SenderAudio
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_audio = openapi_client.SenderAudio() # SenderAudio | Message audio

    try:
        # 🎵 Send media-audio message
        api_response = api_instance.send_message_audio(sender_audio)
        print("The response of MessagesApi->send_message_audio:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_audio: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_audio** | [**SenderAudio**](SenderAudio.md)| Message audio | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_contact**
> SentMessage send_message_contact(sender_contact)

👤 Send contact message

Simple and object, this method allows you to send a contact. You don't need to have it added to your contacts list, all you have to do is fill in the method attributes with the contact information and send. [A few ready examples](https://support.whapi.cloud/help-desk/sending/overview-of-other-methods-for-sending/send-contact-vcard)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_contact import SenderContact
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_contact = openapi_client.SenderContact() # SenderContact | Message contact

    try:
        # 👤 Send contact message
        api_response = api_instance.send_message_contact(sender_contact)
        print("The response of MessagesApi->send_message_contact:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_contact: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_contact** | [**SenderContact**](SenderContact.md)| Message contact | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**413** | Request body too large |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_contact_list**
> SentMessage send_message_contact_list(sender_contact_list)

👥 Send contact list message

Simple and straightforward, this method allows you to send multiple contacts. You don't need to have them in your contacts; just fill the method's attributes with the contact information and send. [A few ready examples](https://support.whapi.cloud/help-desk/sending/overview-of-other-methods-for-sending/send-contact-vcard)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_contact_list import SenderContactList
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_contact_list = openapi_client.SenderContactList() # SenderContactList | Message contact list

    try:
        # 👥 Send contact list message
        api_response = api_instance.send_message_contact_list(sender_contact_list)
        print("The response of MessagesApi->send_message_contact_list:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_contact_list: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_contact_list** | [**SenderContactList**](SenderContactList.md)| Message contact list | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**413** | Request body too large |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_document**
> SentMessage send_message_document(sender_document)

📑 Send media-document message

This method is responsible for sending documents for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_document import SenderDocument
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_document = openapi_client.SenderDocument() # SenderDocument | Message document

    try:
        # 📑 Send media-document message
        api_response = api_instance.send_message_document(sender_document)
        print("The response of MessagesApi->send_message_document:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_document: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_document** | [**SenderDocument**](SenderDocument.md)| Message document | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_gif**
> SentMessage send_message_gif(sender_gif)

🎬 Send media-gif message

Method responsible for sending GIFs to your chats through the API (The file to be sent must be an MP4)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_gif import SenderGif
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_gif = openapi_client.SenderGif() # SenderGif | Message gif

    try:
        # 🎬 Send media-gif message
        api_response = api_instance.send_message_gif(sender_gif)
        print("The response of MessagesApi->send_message_gif:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_gif: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_gif** | [**SenderGif**](SenderGif.md)| Message gif | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_image**
> SentMessage send_message_image(sender_image)

🖼 Send media-image message

This method is responsible for sending images for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_image import SenderImage
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_image = openapi_client.SenderImage() # SenderImage | Message image

    try:
        # 🖼 Send media-image message
        api_response = api_instance.send_message_image(sender_image)
        print("The response of MessagesApi->send_message_image:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_image: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_image** | [**SenderImage**](SenderImage.md)| Message image | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_interactive**
> SentMessage send_message_interactive(sender_interactive)

🎮 Send interactive message

This endpoint is responsible for sending messages with buttons. The section is constantly updated as the functionality of buttons depends on WhatsApp updates. Button sending is currently available. For more information, please visit the [Button Status topic](https://support.whapi.cloud/help-desk/faq/current-status-of-buttons-on-whatsapp).

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_interactive import SenderInteractive
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_interactive = openapi_client.SenderInteractive() # SenderInteractive | Message interactive

    try:
        # 🎮 Send interactive message
        api_response = api_instance.send_message_interactive(sender_interactive)
        print("The response of MessagesApi->send_message_interactive:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_interactive: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_interactive** | [**SenderInteractive**](SenderInteractive.md)| Message interactive | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_link_preview**
> SentMessage send_message_link_preview(sender_link_preview)

📎 Send link preview message

Method responsible for sending links with customize preview to your contacts, it is used to share links so that the user can be redirected to a website. Your link must necessarily be in the Body parameter. It is important for you to know that [the link is only clickable](https://support.whapi.cloud/help-desk/faq/inactive-links-in-whatsapp-messages) if the recipient already has your phone number in their contacts, or if they start a conversation with you

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_link_preview import SenderLinkPreview
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_link_preview = openapi_client.SenderLinkPreview() # SenderLinkPreview | Message link preview send parameters

    try:
        # 📎 Send link preview message
        api_response = api_instance.send_message_link_preview(sender_link_preview)
        print("The response of MessagesApi->send_message_link_preview:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_link_preview: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_link_preview** | [**SenderLinkPreview**](SenderLinkPreview.md)| Message link preview send parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_live_location**
> SentMessage send_message_live_location(sender_live_location)

🧭 Send live location message

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_live_location import SenderLiveLocation
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_live_location = openapi_client.SenderLiveLocation() # SenderLiveLocation | Message live location

    try:
        # 🧭 Send live location message
        api_response = api_instance.send_message_live_location(sender_live_location)
        print("The response of MessagesApi->send_message_live_location:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_live_location: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_live_location** | [**SenderLiveLocation**](SenderLiveLocation.md)| Message live location | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**413** | Request body too large |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_location**
> SentMessage send_message_location(sender_location)

📍 Send location message

Method responsible for sending a fixed location to your contacts, it is mostly used to send an address’s location

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_location import SenderLocation
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_location = openapi_client.SenderLocation() # SenderLocation | Message location

    try:
        # 📍 Send location message
        api_response = api_instance.send_message_location(sender_location)
        print("The response of MessagesApi->send_message_location:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_location: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_location** | [**SenderLocation**](SenderLocation.md)| Message location | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**413** | Request body too large |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_poll**
> SentMessage send_message_poll(sender_poll)

📊 Send poll message

In this method, you can send poll-type messages. Often, it's the polls that replace [the buttons for interactive communication](https://support.whapi.cloud/help-desk/hints/how-to-use-polls-as-buttons)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_poll import SenderPoll
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_poll = openapi_client.SenderPoll() # SenderPoll | Message poll

    try:
        # 📊 Send poll message
        api_response = api_instance.send_message_poll(sender_poll)
        print("The response of MessagesApi->send_message_poll:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_poll: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_poll** | [**SenderPoll**](SenderPoll.md)| Message poll | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_short**
> SentMessage send_message_short(sender_short)

📹 Send media-short video message (PTV)

This method is responsible for sending a short video in the circle for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_short import SenderShort
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_short = openapi_client.SenderShort() # SenderShort | Message short

    try:
        # 📹 Send media-short video message (PTV)
        api_response = api_instance.send_message_short(sender_short)
        print("The response of MessagesApi->send_message_short:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_short: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_short** | [**SenderShort**](SenderShort.md)| Message short | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_sticker**
> SentMessage send_message_sticker(sender_sticker)

🎭 Send media-sticker message

This method is responsible for sending a sticker message for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_sticker import SenderSticker
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_sticker = openapi_client.SenderSticker() # SenderSticker | Message sticker

    try:
        # 🎭 Send media-sticker message
        api_response = api_instance.send_message_sticker(sender_sticker)
        print("The response of MessagesApi->send_message_sticker:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_sticker: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_sticker** | [**SenderSticker**](SenderSticker.md)| Message sticker | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_story**
> SentMessage send_message_story(sender_stories)

👁️‍🗨️ Send story message

The method responsible for sending images or texts to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories import SenderStories
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_stories = openapi_client.SenderStories() # SenderStories | Stories post parameters

    try:
        # 👁️‍🗨️ Send story message
        api_response = api_instance.send_message_story(sender_stories)
        print("The response of MessagesApi->send_message_story:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_story: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories** | [**SenderStories**](SenderStories.md)| Stories post parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_story_audio**
> SentMessage send_message_story_audio(sender_stories_audio)

🎵️ Send story audio message

The method responsible for sending audio to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories_audio import SenderStoriesAudio
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_stories_audio = openapi_client.SenderStoriesAudio() # SenderStoriesAudio | Stories post parameters for audio

    try:
        # 🎵️ Send story audio message
        api_response = api_instance.send_message_story_audio(sender_stories_audio)
        print("The response of MessagesApi->send_message_story_audio:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_story_audio: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories_audio** | [**SenderStoriesAudio**](SenderStoriesAudio.md)| Stories post parameters for audio | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_story_media**
> SentMessage send_message_story_media(media, mime_type=mime_type, no_encode=no_encode, no_cache=no_cache, caption=caption, preview=preview, width=width, height=height, contacts=contacts)

🖼 Send story media message

The method responsible for sending images or video to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.send_media_media import SendMediaMedia
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    media = openapi_client.SendMediaMedia() # SendMediaMedia | 
    mime_type = 'mime_type_example' # str | Mime type of media (optional)
    no_encode = True # bool | Do not use our encoding (optional)
    no_cache = True # bool | Do not use the cache in a request (optional)
    caption = 'caption_example' # str | Optional. Text caption under the media. (optional)
    preview = 'preview_example' # str | Optional. Base64 encoded preview of the media. In JPEG format. (optional)
    width = 56 # int | Width of the media in pixels (optional)
    height = 56 # int | Height of the media in pixels (optional)
    contacts = ['contacts_example'] # List[str] | List of contacts to send the story to (optional)

    try:
        # 🖼 Send story media message
        api_response = api_instance.send_message_story_media(media, mime_type=mime_type, no_encode=no_encode, no_cache=no_cache, caption=caption, preview=preview, width=width, height=height, contacts=contacts)
        print("The response of MessagesApi->send_message_story_media:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_story_media: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **media** | [**SendMediaMedia**](SendMediaMedia.md)|  | 
 **mime_type** | **str**| Mime type of media | [optional] 
 **no_encode** | **bool**| Do not use our encoding | [optional] 
 **no_cache** | **bool**| Do not use the cache in a request | [optional] 
 **caption** | **str**| Optional. Text caption under the media. | [optional] 
 **preview** | **str**| Optional. Base64 encoded preview of the media. In JPEG format. | [optional] 
 **width** | **int**| Width of the media in pixels | [optional] 
 **height** | **int**| Height of the media in pixels | [optional] 
 **contacts** | [**List[str]**](str.md)| List of contacts to send the story to | [optional] 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: multipart/form-data, application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_story_text**
> SentMessage send_message_story_text(sender_stories_text)

💬 Send story text message

The method responsible for sending texts to your status. Remember that statuses disappear after 24 hours.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories_text import SenderStoriesText
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_stories_text = openapi_client.SenderStoriesText() # SenderStoriesText | Text stories post parameters

    try:
        # 💬 Send story text message
        api_response = api_instance.send_message_story_text(sender_stories_text)
        print("The response of MessagesApi->send_message_story_text:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_story_text: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories_text** | [**SenderStoriesText**](SenderStoriesText.md)| Text stories post parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_text**
> SentMessage send_message_text(sender_text)

💬 Send text message

This endpoint will let you send messages to any WhatsApp-enabled phone number or to any WhatsApp Group/Channel using your own number connected to Whapi.Cloud. Follow the instructions if you want to [format text](https://support.whapi.cloud/help-desk/faq/whatsapp-text-formatting), [send a emoji](https://support.whapi.cloud/help-desk/sending/send-emoji) or [use line breaks](https://support.whapi.cloud/help-desk/faq/how-to-send-a-paragraph-line-break).

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_text import SenderText
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_text = openapi_client.SenderText() # SenderText | Message text

    try:
        # 💬 Send text message
        api_response = api_instance.send_message_text(sender_text)
        print("The response of MessagesApi->send_message_text:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_text: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_text** | [**SenderText**](SenderText.md)| Message text | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**413** | Request body too large |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_video**
> SentMessage send_message_video(sender_video)

🎥 Send media-video message

This method is responsible for sending a video message for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_video import SenderVideo
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_video = openapi_client.SenderVideo() # SenderVideo | Message video

    try:
        # 🎥 Send media-video message
        api_response = api_instance.send_message_video(sender_video)
        print("The response of MessagesApi->send_message_video:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_video: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_video** | [**SenderVideo**](SenderVideo.md)| Message video | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_voice**
> SentMessage send_message_voice(sender_voice)

🎤 Send media-voice message

This method is responsible for sending a voice message for chats. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document). However, there are [some nuances](https://support.whapi.cloud/help-desk/sending/overview-of-other-methods-for-sending/send-voice-message) when sending voice messages

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_voice import SenderVoice
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    sender_voice = openapi_client.SenderVoice() # SenderVoice | Message voice

    try:
        # 🎤 Send media-voice message
        api_response = api_instance.send_message_voice(sender_voice)
        print("The response of MessagesApi->send_message_voice:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->send_message_voice: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_voice** | [**SenderVoice**](SenderVoice.md)| Message voice | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for send message |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **star_message**
> ResponseSuccess star_message(message_id, star)

⭐ Star message

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.models.star import Star
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.MessagesApi(api_client)
    message_id = 'message_id_example' # str | Message ID
    star = openapi_client.Star() # Star | Star message

    try:
        # ⭐ Star message
        api_response = api_instance.star_message(message_id, star)
        print("The response of MessagesApi->star_message:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling MessagesApi->star_message: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **message_id** | **str**| Message ID | 
 **star** | [**Star**](Star.md)| Star message | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for star message |  -  |
**404** | Specified message not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

