# openapi_client.NewslettersApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**accept_newsletter_admin_request**](NewslettersApi.md#accept_newsletter_admin_request) | **PUT** /newsletters/{NewsletterID}/admins/{ContactID} | Accept Newsletter admin-request
[**create_newsletter**](NewslettersApi.md#create_newsletter) | **POST** /newsletters | Create newsletter
[**create_newsletter_admin_invite**](NewslettersApi.md#create_newsletter_admin_invite) | **POST** /newsletters/{NewsletterID}/invite/{ContactID} | Create Newsletter admin-invite
[**delete_newsletter**](NewslettersApi.md#delete_newsletter) | **DELETE** /newsletters/{NewsletterID} | Delete newsletter
[**demote_newsletter_admin**](NewslettersApi.md#demote_newsletter_admin) | **DELETE** /newsletters/{NewsletterID}/admins/{ContactID} | Demote Newsletter admin
[**edit_newsletter**](NewslettersApi.md#edit_newsletter) | **PATCH** /newsletters/{NewsletterID} | Edit newsletter
[**find_newsletter**](NewslettersApi.md#find_newsletter) | **GET** /newsletters/find | Find newsletters by filters
[**get_messages_newsletter**](NewslettersApi.md#get_messages_newsletter) | **GET** /newsletters/{NewsletterID}/messages | Get newsletter messages
[**get_newsletter**](NewslettersApi.md#get_newsletter) | **GET** /newsletters/{NewsletterID} | Get newsletter information
[**get_newsletter_by_invite_code**](NewslettersApi.md#get_newsletter_by_invite_code) | **GET** /newsletters/link/{NewsletterInviteCode} | Get newsletter info by invite code
[**get_newsletters**](NewslettersApi.md#get_newsletters) | **GET** /newsletters | Get newsletters
[**recommended_newsletter**](NewslettersApi.md#recommended_newsletter) | **GET** /newsletters/recommended | Get recommended newsletters by country
[**revoke_newsletter_admin_invite**](NewslettersApi.md#revoke_newsletter_admin_invite) | **DELETE** /newsletters/{NewsletterID}/invite/{ContactID} | Revoke Newsletter admin-invite
[**send_newsletter_invite**](NewslettersApi.md#send_newsletter_invite) | **POST** /newsletters/link/{NewsletterInviteCode} | Send newsletter invite link
[**subscribe_newsletter**](NewslettersApi.md#subscribe_newsletter) | **POST** /newsletters/{NewsletterID}/subscription | Subscribe to newsletter
[**subscribe_newsletter_invite**](NewslettersApi.md#subscribe_newsletter_invite) | **POST** /newsletters/invite/{NewsletterInviteCode}/subscription | Subscribe to newsletter by invite code
[**tracking_newsletter**](NewslettersApi.md#tracking_newsletter) | **POST** /newsletters/{NewsletterID}/tracking | Subscribe to newsletter updates
[**unsubscribe_newsletter**](NewslettersApi.md#unsubscribe_newsletter) | **DELETE** /newsletters/{NewsletterID}/subscription | Unsubscribe from newsletter
[**unsubscribe_newsletter_invite**](NewslettersApi.md#unsubscribe_newsletter_invite) | **DELETE** /newsletters/invite/{NewsletterInviteCode}/subscription | Unsubscribe from newsletter by invite code


# **accept_newsletter_admin_request**
> ResponseSuccess accept_newsletter_admin_request(newsletter_id, contact_id)

Accept Newsletter admin-request

This method is responsible for accepting an request to become an administrator of a WhatsApp Channel. This request is a message that you can both send like invitation and receive through the received message webhook

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    contact_id = 'contact_id_example' # str | Contact ID

    try:
        # Accept Newsletter admin-request
        api_response = api_instance.accept_newsletter_admin_request(newsletter_id, contact_id)
        print("The response of NewslettersApi->accept_newsletter_admin_request:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->accept_newsletter_admin_request: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **contact_id** | **str**| Contact ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_newsletter**
> Newsletter create_newsletter(create_newsletter_request)

Create newsletter

This method is responsible for creating a WhatsApp Channel. [How to send a post to WhatsApp Channel](https://support.whapi.cloud/help-desk/channels/send-post-to-whatsapp-channel)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.create_newsletter_request import CreateNewsletterRequest
from openapi_client.models.newsletter import Newsletter
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    create_newsletter_request = {"name":"<Newsletter Title>"} # CreateNewsletterRequest | Newsletter data

    try:
        # Create newsletter
        api_response = api_instance.create_newsletter(create_newsletter_request)
        print("The response of NewslettersApi->create_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->create_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **create_newsletter_request** | [**CreateNewsletterRequest**](CreateNewsletterRequest.md)| Newsletter data | 

### Return type

[**Newsletter**](Newsletter.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for add group |  -  |
**404** | Specified participant not found in contacts list |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_newsletter_admin_invite**
> SentMessage create_newsletter_admin_invite(newsletter_id, contact_id, create_newsletter_admin_invite_request=create_newsletter_admin_invite_request)

Create Newsletter admin-invite

This method is responsible for sending an invitation for WhatsApp Channel administrator. Once the invitation is created, an invitation message will be sent to the contact

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.create_newsletter_admin_invite_request import CreateNewsletterAdminInviteRequest
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    contact_id = 'contact_id_example' # str | Contact ID
    create_newsletter_admin_invite_request = {"message":"<Invite message>"} # CreateNewsletterAdminInviteRequest | Invite data (optional)

    try:
        # Create Newsletter admin-invite
        api_response = api_instance.create_newsletter_admin_invite(newsletter_id, contact_id, create_newsletter_admin_invite_request=create_newsletter_admin_invite_request)
        print("The response of NewslettersApi->create_newsletter_admin_invite:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->create_newsletter_admin_invite: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **contact_id** | **str**| Contact ID | 
 **create_newsletter_admin_invite_request** | [**CreateNewsletterAdminInviteRequest**](CreateNewsletterAdminInviteRequest.md)| Invite data | [optional] 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_newsletter**
> ResponseSuccess delete_newsletter(newsletter_id)

Delete newsletter

This method is responsible for deleting a WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID

    try:
        # Delete newsletter
        api_response = api_instance.delete_newsletter(newsletter_id)
        print("The response of NewslettersApi->delete_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->delete_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need to be owner of newsletter |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **demote_newsletter_admin**
> ResponseSuccess demote_newsletter_admin(newsletter_id, contact_id)

Demote Newsletter admin

This method is responsible for removing a user from the administration of the WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    contact_id = 'contact_id_example' # str | Contact ID

    try:
        # Demote Newsletter admin
        api_response = api_instance.demote_newsletter_admin(newsletter_id, contact_id)
        print("The response of NewslettersApi->demote_newsletter_admin:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->demote_newsletter_admin: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **contact_id** | **str**| Contact ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **edit_newsletter**
> Newsletter edit_newsletter(newsletter_id, edit_newsletter_request)

Edit newsletter

This method is responsible for editing a WhatsApp Newsletter Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.edit_newsletter_request import EditNewsletterRequest
from openapi_client.models.newsletter import Newsletter
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    edit_newsletter_request = {"name":"<Newsletter Title>"} # EditNewsletterRequest | Newsletter data

    try:
        # Edit newsletter
        api_response = api_instance.edit_newsletter(newsletter_id, edit_newsletter_request)
        print("The response of NewslettersApi->edit_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->edit_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **edit_newsletter_request** | [**EditNewsletterRequest**](EditNewsletterRequest.md)| Newsletter data | 

### Return type

[**Newsletter**](Newsletter.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need admin permissions for edit newsletter |  -  |
**404** | Specified newsletter not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **find_newsletter**
> NewslettersListPaged find_newsletter(country_code=country_code, search=search, newsletter_field=newsletter_field, cursor=cursor, count=count, sort=sort)

Find newsletters by filters

This method returns a list of WhatsApp Channels data based on the search performed using filters provided in the request body

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.newsletters_list_paged import NewslettersListPaged
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    country_code = 'country_code_example' # str | Country for search (optional)
    search = 'search_example' # str | Search word (optional)
    newsletter_field = 'newsletter_field_example' # str | Cursor to continue pagination (optional)
    cursor = 'cursor_example' # str | Cursor to continue pagination (optional)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    sort = 'sort_example' # str | Order for items in request (optional)

    try:
        # Find newsletters by filters
        api_response = api_instance.find_newsletter(country_code=country_code, search=search, newsletter_field=newsletter_field, cursor=cursor, count=count, sort=sort)
        print("The response of NewslettersApi->find_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->find_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country_code** | **str**| Country for search | [optional] 
 **search** | **str**| Search word | [optional] 
 **newsletter_field** | **str**| Cursor to continue pagination | [optional] 
 **cursor** | **str**| Cursor to continue pagination | [optional] 
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **sort** | **str**| Order for items in request | [optional] 

### Return type

[**NewslettersListPaged**](NewslettersListPaged.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_messages_newsletter**
> MessagesList get_messages_newsletter(newsletter_id, count=count, before=before, after=after)

Get newsletter messages

The method returns the history of WhatsApp Channel messages

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.messages_list import MessagesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    count = 100 # float | Count of objects to return (optional) (default to 100)
    before = 3.4 # float | Request messages before the specified one (see first and last) (optional)
    after = 3.4 # float | Request messages after the specified one (see first and last) (optional)

    try:
        # Get newsletter messages
        api_response = api_instance.get_messages_newsletter(newsletter_id, count=count, before=before, after=after)
        print("The response of NewslettersApi->get_messages_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->get_messages_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **before** | **float**| Request messages before the specified one (see first and last) | [optional] 
 **after** | **float**| Request messages after the specified one (see first and last) | [optional] 

### Return type

[**MessagesList**](MessagesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_newsletter**
> MessagesList get_newsletter(newsletter_id, user_role=user_role)

Get newsletter information

This method returns the metadata of a WhatsApp Channel, including all newsletter information and its views

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.messages_list import MessagesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    user_role = 'user_role_example' # str | User's role regarding the newsletter (optional)

    try:
        # Get newsletter information
        api_response = api_instance.get_newsletter(newsletter_id, user_role=user_role)
        print("The response of NewslettersApi->get_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->get_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **user_role** | **str**| User&#39;s role regarding the newsletter | [optional] 

### Return type

[**MessagesList**](MessagesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_newsletter_by_invite_code**
> Newsletter get_newsletter_by_invite_code(newsletter_invite_code)

Get newsletter info by invite code

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.newsletter import Newsletter
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_invite_code = 'newsletter_invite_code_example' # str | Newsletter Invite Code

    try:
        # Get newsletter info by invite code
        api_response = api_instance.get_newsletter_by_invite_code(newsletter_invite_code)
        print("The response of NewslettersApi->get_newsletter_by_invite_code:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->get_newsletter_by_invite_code: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_invite_code** | **str**| Newsletter Invite Code | 

### Return type

[**Newsletter**](Newsletter.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_newsletters**
> NewslettersList get_newsletters(count=count, offset=offset)

Get newsletters

This method returns a list with metadata of your own WhatsApp Channel and followed Channels, including all Channel information and their views.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.newsletters_list import NewslettersList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)

    try:
        # Get newsletters
        api_response = api_instance.get_newsletters(count=count, offset=offset)
        print("The response of NewslettersApi->get_newsletters:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->get_newsletters: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 

### Return type

[**NewslettersList**](NewslettersList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **recommended_newsletter**
> NewslettersListPaged recommended_newsletter(country_code=country_code, cursor=cursor, count=count)

Get recommended newsletters by country

This method returns a list of WhatsApp Channels data based on the search performed using filters provided in the request body

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.newsletters_list_paged import NewslettersListPaged
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    country_code = 'country_code_example' # str | Country for search (optional)
    cursor = 'cursor_example' # str | Cursor to continue pagination (optional)
    count = 100 # float | Count of objects to return (optional) (default to 100)

    try:
        # Get recommended newsletters by country
        api_response = api_instance.recommended_newsletter(country_code=country_code, cursor=cursor, count=count)
        print("The response of NewslettersApi->recommended_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->recommended_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country_code** | **str**| Country for search | [optional] 
 **cursor** | **str**| Cursor to continue pagination | [optional] 
 **count** | **float**| Count of objects to return | [optional] [default to 100]

### Return type

[**NewslettersListPaged**](NewslettersListPaged.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **revoke_newsletter_admin_invite**
> ResponseSuccess revoke_newsletter_admin_invite(newsletter_id, contact_id)

Revoke Newsletter admin-invite

This method is responsible for revoking an invitation for WhatsApp Channel administrator.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID
    contact_id = 'contact_id_example' # str | Contact ID

    try:
        # Revoke Newsletter admin-invite
        api_response = api_instance.revoke_newsletter_admin_invite(newsletter_id, contact_id)
        print("The response of NewslettersApi->revoke_newsletter_admin_invite:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->revoke_newsletter_admin_invite: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 
 **contact_id** | **str**| Contact ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_newsletter_invite**
> SentMessage send_newsletter_invite(newsletter_invite_code, sender_newsletter_invite_by_code)

Send newsletter invite link

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_newsletter_invite_by_code import SenderNewsletterInviteByCode
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_invite_code = 'newsletter_invite_code_example' # str | Newsletter Invite Code
    sender_newsletter_invite_by_code = openapi_client.SenderNewsletterInviteByCode() # SenderNewsletterInviteByCode | Newsletter invite link

    try:
        # Send newsletter invite link
        api_response = api_instance.send_newsletter_invite(newsletter_invite_code, sender_newsletter_invite_by_code)
        print("The response of NewslettersApi->send_newsletter_invite:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->send_newsletter_invite: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_invite_code** | **str**| Newsletter Invite Code | 
 **sender_newsletter_invite_by_code** | [**SenderNewsletterInviteByCode**](SenderNewsletterInviteByCode.md)| Newsletter invite link | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for this action |  -  |
**404** | Specified newsletter not found |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscribe_newsletter**
> ResponseSuccess subscribe_newsletter(newsletter_id)

Subscribe to newsletter

This method is responsible for following a WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID

    try:
        # Subscribe to newsletter
        api_response = api_instance.subscribe_newsletter(newsletter_id)
        print("The response of NewslettersApi->subscribe_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->subscribe_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscribe_newsletter_invite**
> ResponseSuccess subscribe_newsletter_invite(newsletter_invite_code)

Subscribe to newsletter by invite code

This method is responsible for following a WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_invite_code = 'newsletter_invite_code_example' # str | Newsletter Invite Code

    try:
        # Subscribe to newsletter by invite code
        api_response = api_instance.subscribe_newsletter_invite(newsletter_invite_code)
        print("The response of NewslettersApi->subscribe_newsletter_invite:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->subscribe_newsletter_invite: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_invite_code** | **str**| Newsletter Invite Code | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **tracking_newsletter**
> ResponseSuccess tracking_newsletter(newsletter_id)

Subscribe to newsletter updates

It is necessary to receive notifications about new votes in the polls

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID

    try:
        # Subscribe to newsletter updates
        api_response = api_instance.tracking_newsletter(newsletter_id)
        print("The response of NewslettersApi->tracking_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->tracking_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **unsubscribe_newsletter**
> ResponseSuccess unsubscribe_newsletter(newsletter_id)

Unsubscribe from newsletter

This method is responsible for unfollowing a WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_id = 'newsletter_id_example' # str | Newsletter ID

    try:
        # Unsubscribe from newsletter
        api_response = api_instance.unsubscribe_newsletter(newsletter_id)
        print("The response of NewslettersApi->unsubscribe_newsletter:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->unsubscribe_newsletter: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_id** | **str**| Newsletter ID | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **unsubscribe_newsletter_invite**
> ResponseSuccess unsubscribe_newsletter_invite(newsletter_invite_code)

Unsubscribe from newsletter by invite code

This method is responsible for unfollowing a WhatsApp Channel

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.NewslettersApi(api_client)
    newsletter_invite_code = 'newsletter_invite_code_example' # str | Newsletter Invite Code

    try:
        # Unsubscribe from newsletter by invite code
        api_response = api_instance.unsubscribe_newsletter_invite(newsletter_invite_code)
        print("The response of NewslettersApi->unsubscribe_newsletter_invite:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling NewslettersApi->unsubscribe_newsletter_invite: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newsletter_invite_code** | **str**| Newsletter Invite Code | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**404** | Specified newsletter not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

