# openapi_client.PresencesApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_presence**](PresencesApi.md#get_presence) | **GET** /presences/{EntryID} | Get presence
[**send_me_presence**](PresencesApi.md#send_me_presence) | **PUT** /presences/me | Send online or offline presence
[**send_presence**](PresencesApi.md#send_presence) | **PUT** /presences/{EntryID} | Send typing or recording presence
[**subscribe_presence**](PresencesApi.md#subscribe_presence) | **POST** /presences/{EntryID} | Subscribe to presence


# **get_presence**
> Presence get_presence(entry_id)

Get presence

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.presence import Presence
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.PresencesApi(api_client)
    entry_id = openapi_client.GetPresenceEntryIDParameter() # GetPresenceEntryIDParameter | Contact or group id

    try:
        # Get presence
        api_response = api_instance.get_presence(entry_id)
        print("The response of PresencesApi->get_presence:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling PresencesApi->get_presence: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **entry_id** | [**GetPresenceEntryIDParameter**](.md)| Contact or group id | 

### Return type

[**Presence**](Presence.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization to get presence |  -  |
**404** | Specified contact presence not subscribed |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_me_presence**
> CheckContactResponse send_me_presence(send_me_presence_request=send_me_presence_request)

Send online or offline presence

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.check_contact_response import CheckContactResponse
from openapi_client.models.send_me_presence_request import SendMePresenceRequest
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.PresencesApi(api_client)
    send_me_presence_request = openapi_client.SendMePresenceRequest() # SendMePresenceRequest |  (optional)

    try:
        # Send online or offline presence
        api_response = api_instance.send_me_presence(send_me_presence_request=send_me_presence_request)
        print("The response of PresencesApi->send_me_presence:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling PresencesApi->send_me_presence: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **send_me_presence_request** | [**SendMePresenceRequest**](SendMePresenceRequest.md)|  | [optional] 

### Return type

[**CheckContactResponse**](CheckContactResponse.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization to send online or offline presence |  -  |
**404** | Specified contact not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_presence**
> CheckContactResponse send_presence(entry_id, send_presence_request=send_presence_request)

Send typing or recording presence

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.check_contact_response import CheckContactResponse
from openapi_client.models.send_presence_request import SendPresenceRequest
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.PresencesApi(api_client)
    entry_id = openapi_client.GetPresenceEntryIDParameter() # GetPresenceEntryIDParameter | Contact or group id
    send_presence_request = openapi_client.SendPresenceRequest() # SendPresenceRequest |  (optional)

    try:
        # Send typing or recording presence
        api_response = api_instance.send_presence(entry_id, send_presence_request=send_presence_request)
        print("The response of PresencesApi->send_presence:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling PresencesApi->send_presence: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **entry_id** | [**GetPresenceEntryIDParameter**](.md)| Contact or group id | 
 **send_presence_request** | [**SendPresenceRequest**](SendPresenceRequest.md)|  | [optional] 

### Return type

[**CheckContactResponse**](CheckContactResponse.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization to send typing or recording presence |  -  |
**404** | Specified contact not found |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **subscribe_presence**
> CheckContactResponse subscribe_presence(entry_id)

Subscribe to presence

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.check_contact_response import CheckContactResponse
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.PresencesApi(api_client)
    entry_id = openapi_client.GetPresenceEntryIDParameter() # GetPresenceEntryIDParameter | Contact or group id

    try:
        # Subscribe to presence
        api_response = api_instance.subscribe_presence(entry_id)
        print("The response of PresencesApi->subscribe_presence:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling PresencesApi->subscribe_presence: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **entry_id** | [**GetPresenceEntryIDParameter**](.md)| Contact or group id | 

### Return type

[**CheckContactResponse**](CheckContactResponse.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization to subscribe to presence |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Specified contact not found in whatsapp |  -  |
**409** | Specified contact presence already subscribed |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

