# openapi_client.StoriesApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_story**](StoriesApi.md#create_story) | **POST** /stories | Create &amp; publish story
[**create_story_audio**](StoriesApi.md#create_story_audio) | **POST** /stories/send/audio | 🎵️ Post audio story
[**create_story_media**](StoriesApi.md#create_story_media) | **POST** /stories/send/media | 🖼 Post media story
[**create_story_text**](StoriesApi.md#create_story_text) | **POST** /stories/send/text | 💬 Post text story
[**get_stories**](StoriesApi.md#get_stories) | **GET** /stories | Get list of stories
[**send_message_story_text_0**](StoriesApi.md#send_message_story_text_0) | **POST** /messages/story/text | 💬 Send story text message


# **create_story**
> SentMessage create_story(sender_stories)

Create & publish story

The method responsible for sending images or texts to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories import SenderStories
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    sender_stories = openapi_client.SenderStories() # SenderStories | Stories post parameters

    try:
        # Create & publish story
        api_response = api_instance.create_story(sender_stories)
        print("The response of StoriesApi->create_story:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->create_story: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories** | [**SenderStories**](SenderStories.md)| Stories post parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_story_audio**
> SentMessage create_story_audio(sender_stories_audio)

🎵️ Post audio story

The method responsible for sending audio to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories_audio import SenderStoriesAudio
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    sender_stories_audio = openapi_client.SenderStoriesAudio() # SenderStoriesAudio | Stories post parameters for audio

    try:
        # 🎵️ Post audio story
        api_response = api_instance.create_story_audio(sender_stories_audio)
        print("The response of StoriesApi->create_story_audio:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->create_story_audio: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories_audio** | [**SenderStoriesAudio**](SenderStoriesAudio.md)| Stories post parameters for audio | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_story_media**
> SentMessage create_story_media(media, mime_type=mime_type, no_encode=no_encode, no_cache=no_cache, caption=caption, preview=preview, width=width, height=height, contacts=contacts)

🖼 Post media story

The method responsible for sending images or video to your status. Remember that statuses disappear after 24 hours. The requirements for [sending all media types are identical](https://support.whapi.cloud/help-desk/sending/send-video-audio-image-document)

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.send_media_media import SendMediaMedia
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    media = openapi_client.SendMediaMedia() # SendMediaMedia | 
    mime_type = 'mime_type_example' # str | Mime type of media (optional)
    no_encode = True # bool | Do not use our encoding (optional)
    no_cache = True # bool | Do not use the cache in a request (optional)
    caption = 'caption_example' # str | Optional. Text caption under the media. (optional)
    preview = 'preview_example' # str | Optional. Base64 encoded preview of the media. In JPEG format. (optional)
    width = 56 # int | Width of the media in pixels (optional)
    height = 56 # int | Height of the media in pixels (optional)
    contacts = ['contacts_example'] # List[str] | List of contacts to send the story to (optional)

    try:
        # 🖼 Post media story
        api_response = api_instance.create_story_media(media, mime_type=mime_type, no_encode=no_encode, no_cache=no_cache, caption=caption, preview=preview, width=width, height=height, contacts=contacts)
        print("The response of StoriesApi->create_story_media:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->create_story_media: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **media** | [**SendMediaMedia**](SendMediaMedia.md)|  | 
 **mime_type** | **str**| Mime type of media | [optional] 
 **no_encode** | **bool**| Do not use our encoding | [optional] 
 **no_cache** | **bool**| Do not use the cache in a request | [optional] 
 **caption** | **str**| Optional. Text caption under the media. | [optional] 
 **preview** | **str**| Optional. Base64 encoded preview of the media. In JPEG format. | [optional] 
 **width** | **int**| Width of the media in pixels | [optional] 
 **height** | **int**| Height of the media in pixels | [optional] 
 **contacts** | [**List[str]**](str.md)| List of contacts to send the story to | [optional] 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: multipart/form-data, application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **create_story_text**
> SentMessage create_story_text(sender_stories_text)

💬 Post text story

The method responsible for sending texts to your status. Remember that statuses disappear after 24 hours.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories_text import SenderStoriesText
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    sender_stories_text = openapi_client.SenderStoriesText() # SenderStoriesText | Text stories post parameters

    try:
        # 💬 Post text story
        api_response = api_instance.create_story_text(sender_stories_text)
        print("The response of StoriesApi->create_story_text:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->create_story_text: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories_text** | [**SenderStoriesText**](SenderStoriesText.md)| Text stories post parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_stories**
> MessagesList get_stories(count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me)

Get list of stories

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.messages_list import MessagesList
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    count = 100 # float | Count of objects to return (optional) (default to 100)
    offset = 3.4 # float | Offset of objects to return (optional)
    time_from = 3.4 # float | Timestamp from which to get objects (optional)
    time_to = 3.4 # float | Timestamp up to which to get objects (optional)
    normal_types = True # bool | If false, include system messages (optional)
    author = 'author_example' # str | To filter by author (Contact ID) (optional)
    from_me = True # bool | If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. (optional)

    try:
        # Get list of stories
        api_response = api_instance.get_stories(count=count, offset=offset, time_from=time_from, time_to=time_to, normal_types=normal_types, author=author, from_me=from_me)
        print("The response of StoriesApi->get_stories:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->get_stories: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **count** | **float**| Count of objects to return | [optional] [default to 100]
 **offset** | **float**| Offset of objects to return | [optional] 
 **time_from** | **float**| Timestamp from which to get objects | [optional] 
 **time_to** | **float**| Timestamp up to which to get objects | [optional] 
 **normal_types** | **bool**| If false, include system messages | [optional] 
 **author** | **str**| To filter by author (Contact ID) | [optional] 
 **from_me** | **bool**| If true, only return messages sent by the authenticated user. If false, only return messages sent by other users. | [optional] 

### Return type

[**MessagesList**](MessagesList.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Wrong request parameters |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **send_message_story_text_0**
> SentMessage send_message_story_text_0(sender_stories_text)

💬 Send story text message

The method responsible for sending texts to your status. Remember that statuses disappear after 24 hours.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.sender_stories_text import SenderStoriesText
from openapi_client.models.sent_message import SentMessage
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.StoriesApi(api_client)
    sender_stories_text = openapi_client.SenderStoriesText() # SenderStoriesText | Text stories post parameters

    try:
        # 💬 Send story text message
        api_response = api_instance.send_message_story_text_0(sender_stories_text)
        print("The response of StoriesApi->send_message_story_text_0:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling StoriesApi->send_message_story_text_0: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sender_stories_text** | [**SenderStoriesText**](SenderStoriesText.md)| Text stories post parameters | 

### Return type

[**SentMessage**](SentMessage.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**201** | Created |  -  |
**400** | Wrong request parameters |  -  |
**401** | Need channel authorization for posting stories |  -  |
**402** | Trial version limit exceeded |  -  |
**403** | It is forbidden to send to this group/recipient |  -  |
**404** | Media with specified id not found |  -  |
**413** | Request media too large |  -  |
**415** | Unsupported media type |  -  |
**429** | Too many requests |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

