# openapi_client.UsersApi

All URIs are relative to *https://gate.whapi.cloud*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_user_profile**](UsersApi.md#get_user_profile) | **GET** /users/profile | User info
[**login_user**](UsersApi.md#login_user) | **GET** /users/login | Login user with QR-base64
[**login_user_image**](UsersApi.md#login_user_image) | **GET** /users/login/image | Login user with QR-image
[**login_user_row_data**](UsersApi.md#login_user_row_data) | **GET** /users/login/rowdata | Login user with QR-rowdata
[**login_user_via_auth_code**](UsersApi.md#login_user_via_auth_code) | **GET** /users/login/{PhoneNumber} | Get auth code by phone number
[**login_user_via_mobile**](UsersApi.md#login_user_via_mobile) | **POST** /users/login/mobile | Login in whatsapp with phone number
[**logout_user**](UsersApi.md#logout_user) | **POST** /users/logout | Logout user
[**update_user_profile**](UsersApi.md#update_user_profile) | **PATCH** /users/profile | Update user info


# **get_user_profile**
> UserProfile get_user_profile()

User info

The method allows you to get information about your WhatsApp profile

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.user_profile import UserProfile
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)

    try:
        # User info
        api_response = api_instance.get_user_profile()
        print("The response of UsersApi->get_user_profile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->get_user_profile: %s\n" % e)
```



### Parameters

This endpoint does not need any parameter.

### Return type

[**UserProfile**](UserProfile.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login_user**
> QR login_user(wakeup=wakeup, qr_parameters=qr_parameters)

Login user with QR-base64

This method returns an image of the type base64. You can render this in a component of the type image that is compatible with the language that you use to program. Just like on WhatsApp Web you will need to read a QR code to connect to Whapi.Cloud. There are two ways that you can do the reading of the QR code. Connect through our dashboard panel or Make this experience available within your own application.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.qr import QR
from openapi_client.models.qr_parameters import QRParameters
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    wakeup = True # bool | If set to false, the channel will not launch (optional) (default to True)
    qr_parameters = {"size":200,"width":300,"height":300,"color_dark":"#000000","color_light":"#ffffff"} # QRParameters | Parameters for generating QR code (optional)

    try:
        # Login user with QR-base64
        api_response = api_instance.login_user(wakeup=wakeup, qr_parameters=qr_parameters)
        print("The response of UsersApi->login_user:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->login_user: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wakeup** | **bool**| If set to false, the channel will not launch | [optional] [default to True]
 **qr_parameters** | [**QRParameters**](QRParameters.md)| Parameters for generating QR code | [optional] 

### Return type

[**QR**](QR.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**406** | Not acceptable for mobile type channel |  -  |
**409** | Channel already authenticated |  -  |
**422** | Render QR failed |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login_user_image**
> bytearray login_user_image(wakeup=wakeup, qr_parameters=qr_parameters)

Login user with QR-image

This method returns an image. Just like on WhatsApp Web you will need to read a QR code to connect to Whapi.Cloud. There are two ways that you can do the reading of the QR code. Connect through our dashboard panel or Make this experience available within your own application.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.qr_parameters import QRParameters
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    wakeup = True # bool | If set to false, the channel will not launch (optional) (default to True)
    qr_parameters = {"size":200,"width":300,"height":300,"color_dark":"#000000","color_light":"#ffffff"} # QRParameters | Parameters for generating QR code (optional)

    try:
        # Login user with QR-image
        api_response = api_instance.login_user_image(wakeup=wakeup, qr_parameters=qr_parameters)
        print("The response of UsersApi->login_user_image:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->login_user_image: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wakeup** | **bool**| If set to false, the channel will not launch | [optional] [default to True]
 **qr_parameters** | [**QRParameters**](QRParameters.md)| Parameters for generating QR code | [optional] 

### Return type

**bytearray**

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: image/png, application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login_user_row_data**
> QR login_user_row_data(wakeup=wakeup)

Login user with QR-rowdata

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.qr import QR
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    wakeup = True # bool | If set to false, the channel will not launch (optional) (default to True)

    try:
        # Login user with QR-rowdata
        api_response = api_instance.login_user_row_data(wakeup=wakeup)
        print("The response of UsersApi->login_user_row_data:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->login_user_row_data: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **wakeup** | **bool**| If set to false, the channel will not launch | [optional] [default to True]

### Return type

[**QR**](QR.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**406** | Not acceptable for mobile type channel |  -  |
**409** | Channel already authenticated |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login_user_via_auth_code**
> AuthCode login_user_via_auth_code(phone_number)

Get auth code by phone number

This method returns a code that allows you to connect the phone number to the API without the need to scan a QR code, simply by entering the generated code.

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.auth_code import AuthCode
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    phone_number = 'phone_number_example' # str | Phone number without + and spaces, only digits

    try:
        # Get auth code by phone number
        api_response = api_instance.login_user_via_auth_code(phone_number)
        print("The response of UsersApi->login_user_via_auth_code:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->login_user_via_auth_code: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **phone_number** | **str**| Phone number without + and spaces, only digits | 

### Return type

[**AuthCode**](AuthCode.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Invalid phone number |  -  |
**406** | Not acceptable for mobile type channel |  -  |
**409** | Channel already authenticated |  -  |
**422** | Render QR failed |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **login_user_via_mobile**
> MobileLoginStatus login_user_via_mobile(request_mobile_login)

Login in whatsapp with phone number

Allows you to register a number on WhatsApp. Requires mandatory use of mobile proxies!

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.mobile_login_status import MobileLoginStatus
from openapi_client.models.request_mobile_login import RequestMobileLogin
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    request_mobile_login = openapi_client.RequestMobileLogin() # RequestMobileLogin | Request body for login mobile

    try:
        # Login in whatsapp with phone number
        api_response = api_instance.login_user_via_mobile(request_mobile_login)
        print("The response of UsersApi->login_user_via_mobile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->login_user_via_mobile: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **request_mobile_login** | [**RequestMobileLogin**](RequestMobileLogin.md)| Request body for login mobile | 

### Return type

[**MobileLoginStatus**](MobileLoginStatus.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**400** | Invalid phone number |  -  |
**403** | Forbidden without a proxy |  -  |
**406** | Acceptable only for mobile type channel |  -  |
**409** | Channel already authenticated |  -  |
**412** | A different phone number has been provided. To authorize with a new number, please logout and initiate mobile login process again |  -  |
**422** | Render QR failed |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **logout_user**
> ResponseSuccess logout_user()

Logout user

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)

    try:
        # Logout user
        api_response = api_instance.logout_user()
        print("The response of UsersApi->logout_user:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->logout_user: %s\n" % e)
```



### Parameters

This endpoint does not need any parameter.

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**409** | Channel already logged out |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_user_profile**
> ResponseSuccess update_user_profile(user_profile_update)

Update user info

This method is responsible for changing the details of your WhatsApp profile

### Example

* Api Key Authentication (tokenAuth):
* Bearer (token) Authentication (bearerAuth):

```python
import openapi_client
from openapi_client.models.response_success import ResponseSuccess
from openapi_client.models.user_profile_update import UserProfileUpdate
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://gate.whapi.cloud
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://gate.whapi.cloud"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: tokenAuth
configuration.api_key['tokenAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['tokenAuth'] = 'Bearer'

# Configure Bearer authorization (token): bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.UsersApi(api_client)
    user_profile_update = {"name":"Some Cool Name","about":"Some Cool About","icon":"https://pps.whatsapp.net/v/..."} # UserProfileUpdate | Change user profile

    try:
        # Update user info
        api_response = api_instance.update_user_profile(user_profile_update)
        print("The response of UsersApi->update_user_profile:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling UsersApi->update_user_profile: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user_profile_update** | [**UserProfileUpdate**](UserProfileUpdate.md)| Change user profile | 

### Return type

[**ResponseSuccess**](ResponseSuccess.md)

### Authorization

[tokenAuth](../README.md#tokenAuth), [bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json, multipart/form-data
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | OK |  -  |
**500** | Internal Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

