# coding: utf-8

"""
    Whapi API

    Sending and receiving messages using HTTP requests. Fixed price with no hidden fees, without limits and restrictions. You will be able to send and receive text/media/files/locations/goods/orders/polls messages via WhatsApp in private or group chats. Guides and SDK can be found on our website.

    The version of the OpenAPI document: 1.8.7
    Contact: care@whapi.cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from openapi_client.models.label import Label
from openapi_client.models.message import Message
from typing import Optional, Set
from typing_extensions import Self

class Newsletter(BaseModel):
    """
    Newsletter
    """ # noqa: E501
    id: Annotated[str, Field(strict=True)] = Field(description="Chat ID")
    name: StrictStr = Field(description="Newsletter name")
    type: StrictStr = Field(description="Chat type")
    timestamp: Optional[StrictInt] = Field(default=None, description="Chat timestamp")
    chat_pic: Optional[StrictStr] = Field(default=None, description="Chat picture URL")
    chat_pic_full: Optional[StrictStr] = Field(default=None, description="Chat full picture URL")
    pin: Optional[StrictBool] = Field(default=None, description="Is chat pinned")
    mute: Optional[StrictBool] = Field(default=None, description="Is chat muted")
    mute_until: Optional[StrictInt] = Field(default=None, description="Chat mute until")
    archive: Optional[StrictBool] = Field(default=None, description="Is chat archived")
    unread: Optional[StrictInt] = Field(default=None, description="Unread messages count")
    unread_mention: Optional[StrictBool] = Field(default=None, description="Is chat unread mention")
    read_only: Optional[StrictBool] = Field(default=None, description="Is chat read only")
    not_spam: Optional[StrictBool] = Field(default=None, description="Is chat not spam")
    last_message: Optional[Message] = None
    labels: Optional[List[Label]] = Field(default=None, description="Labels associated with chat")
    name_at: Optional[StrictInt] = Field(default=None, description="Newsletter name change timestamp")
    description: Optional[StrictStr] = Field(default=None, description="Newsletter description")
    description_at: Optional[StrictStr] = Field(default=None, description="Newsletter description change timestamp")
    subscribers_count: Optional[StrictInt] = Field(default=None, description="Newsletter subscribers count")
    created_at: Optional[StrictInt] = Field(default=None, description="Newsletter creation timestamp")
    invite_code: Optional[StrictStr] = Field(default=None, description="Newsletter invite code")
    handle: Optional[StrictStr] = Field(default=None, description="Newsletter handle")
    verification: Optional[StrictBool] = Field(default=None, description="Is newsletter verified")
    preview: Optional[StrictStr] = Field(default=None, description="Newsletter preview URL")
    role: Optional[StrictStr] = Field(default=None, description="User's role regarding the newsletter")
    __properties: ClassVar[List[str]] = ["id", "name", "type", "timestamp", "chat_pic", "chat_pic_full", "pin", "mute", "mute_until", "archive", "unread", "unread_mention", "read_only", "not_spam", "last_message", "labels", "name_at", "description", "description_at", "subscribers_count", "created_at", "invite_code", "handle", "verification", "preview", "role"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\d-]{10,31}@[\w\.]{1,}$", value):
            raise ValueError(r"must validate the regular expression /^[\d-]{10,31}@[\w\.]{1,}$/")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['group', 'contact', 'broadcast', 'newsletter', 'unknown']):
            raise ValueError("must be one of enum values ('group', 'contact', 'broadcast', 'newsletter', 'unknown')")
        return value

    @field_validator('role')
    def role_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['subscriber', 'admin', 'guest', 'owner']):
            raise ValueError("must be one of enum values ('subscriber', 'admin', 'guest', 'owner')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Newsletter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of last_message
        if self.last_message:
            _dict['last_message'] = self.last_message.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict['labels'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Newsletter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "type": obj.get("type"),
            "timestamp": obj.get("timestamp"),
            "chat_pic": obj.get("chat_pic"),
            "chat_pic_full": obj.get("chat_pic_full"),
            "pin": obj.get("pin"),
            "mute": obj.get("mute"),
            "mute_until": obj.get("mute_until"),
            "archive": obj.get("archive"),
            "unread": obj.get("unread"),
            "unread_mention": obj.get("unread_mention"),
            "read_only": obj.get("read_only"),
            "not_spam": obj.get("not_spam"),
            "last_message": Message.from_dict(obj["last_message"]) if obj.get("last_message") is not None else None,
            "labels": [Label.from_dict(_item) for _item in obj["labels"]] if obj.get("labels") is not None else None,
            "name_at": obj.get("name_at"),
            "description": obj.get("description"),
            "description_at": obj.get("description_at"),
            "subscribers_count": obj.get("subscribers_count"),
            "created_at": obj.get("created_at"),
            "invite_code": obj.get("invite_code"),
            "handle": obj.get("handle"),
            "verification": obj.get("verification"),
            "preview": obj.get("preview"),
            "role": obj.get("role")
        })
        return _obj


