# coding: utf-8

"""
    Whapi API

    Sending and receiving messages using HTTP requests. Fixed price with no hidden fees, without limits and restrictions. You will be able to send and receive text/media/files/locations/goods/orders/polls messages via WhatsApp in private or group chats. Guides and SDK can be found on our website.

    The version of the OpenAPI document: 1.8.7
    Contact: care@whapi.cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SenderLocation(BaseModel):
    """
    SenderLocation
    """ # noqa: E501
    to: Annotated[str, Field(strict=True)] = Field(description="Use the phone number or [Chat ID](https://support.whapi.cloud/help-desk/faq/chat-id.-what-is-it-and-how-to-get-it) of the contact/group/channel to which you want to send the message. Use [Get groups](https://whapi.readme.io/reference/getgroups) to get the group ID.")
    quoted: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Message ID of the message to be quoted")
    ephemeral: Optional[Annotated[int, Field(le=604800, strict=True, ge=1)]] = Field(default=None, description="Time in seconds for the message to be deleted. The Disappearing messages setting should be enabled in the chat where you are sending this message.")
    edit: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="Message ID of the message to be edited")
    latitude: Union[StrictFloat, StrictInt] = Field(description="Latitude of location being sent")
    longitude: Union[StrictFloat, StrictInt] = Field(description="Longitude of location being sent")
    address: Optional[StrictStr] = Field(default=None, description="Address of the location")
    name: Optional[StrictStr] = Field(default=None, description="Name of the location")
    url: Optional[StrictStr] = Field(default=None, description="URL for the website where the user downloaded the location information")
    preview: Optional[StrictStr] = Field(default=None, description="Optional. Base64 encoded preview of the media. In JPEG format.")
    accuracy: Optional[StrictInt] = Field(default=None, description="Accuracy of the location in meters")
    speed: Optional[StrictInt] = Field(default=None, description="Speed of the location in meters per second")
    degrees: Optional[StrictInt] = Field(default=None, description="Degrees clockwise from true north")
    comment: Optional[StrictStr] = Field(default=None, description="Optional. Comment for the location")
    view_once: Optional[StrictBool] = Field(default=None, description="Is view once")
    __properties: ClassVar[List[str]] = ["to", "quoted", "ephemeral", "edit", "latitude", "longitude", "address", "name", "url", "preview", "accuracy", "speed", "degrees", "comment", "view_once"]

    @field_validator('to')
    def to_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\d-]{10,31}(@[\w\.]{1,})?$", value):
            raise ValueError(r"must validate the regular expression /^[\d-]{10,31}(@[\w\.]{1,})?$/")
        return value

    @field_validator('quoted')
    def quoted_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Za-z0-9._]{4,23}-[A-Za-z0-9._]{4,14}(-[A-Za-z0-9._]{4,10})?(-[A-Za-z0-9._]{4,10})?$", value):
            raise ValueError(r"must validate the regular expression /^[A-Za-z0-9._]{4,23}-[A-Za-z0-9._]{4,14}(-[A-Za-z0-9._]{4,10})?(-[A-Za-z0-9._]{4,10})?$/")
        return value

    @field_validator('edit')
    def edit_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Za-z0-9._]{4,23}-[A-Za-z0-9._]{4,14}(-[A-Za-z0-9._]{4,10})?(-[A-Za-z0-9._]{4,10})?$", value):
            raise ValueError(r"must validate the regular expression /^[A-Za-z0-9._]{4,23}-[A-Za-z0-9._]{4,14}(-[A-Za-z0-9._]{4,10})?(-[A-Za-z0-9._]{4,10})?$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SenderLocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SenderLocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "to": obj.get("to"),
            "quoted": obj.get("quoted"),
            "ephemeral": obj.get("ephemeral"),
            "edit": obj.get("edit"),
            "latitude": obj.get("latitude"),
            "longitude": obj.get("longitude"),
            "address": obj.get("address"),
            "name": obj.get("name"),
            "url": obj.get("url"),
            "preview": obj.get("preview"),
            "accuracy": obj.get("accuracy"),
            "speed": obj.get("speed"),
            "degrees": obj.get("degrees"),
            "comment": obj.get("comment"),
            "view_once": obj.get("view_once")
        })
        return _obj


